src/hg/hgTracks/hgTracks.h 1.189
1.189 2009/11/10 05:48:18 kent
Changing bbiFileName field in track to bbiFile, so that it is kept open rather than repeatedly opened and closed. This avoids round trips to remote servers. Also starting to put in some stuff for tracks hosted on remote MySQL servers, though this is not complete.
Index: src/hg/hgTracks/hgTracks.h
===================================================================
RCS file: /projects/compbio/cvsroot/kent/src/hg/hgTracks/hgTracks.h,v
retrieving revision 1.188
retrieving revision 1.189
diff -b -B -U 4 -r1.188 -r1.189
--- src/hg/hgTracks/hgTracks.h 1 Nov 2009 19:46:04 -0000 1.188
+++ src/hg/hgTracks/hgTracks.h 10 Nov 2009 05:48:18 -0000 1.189
@@ -147,13 +147,20 @@
float minRange, maxRange; /*min and max range for sample tracks 0.0 to 1000.0*/
float scaleRange; /* What to scale samples by to get logical 0-1 */
double graphUpperLimit, graphLowerLimit; /* Limits of actual data in window for wigs. */
- char *bbiFileName; /* File name for bigWig or bigBed. */
+ struct bbiFile *bbiFile; /* Associated bbiFile for bigWig or bigBed. */
int bedSize; /* Number of fields if a bed file. */
boolean isBigBed; /* If a bed, is it a bigBed? */
+ boolean isRemoteSql; /* Is using a remote mySQL connection. */
+ char *remoteSqlHost; /* Host machine name for remote DB. */
+ char *remoteSqlUser; /* User name for remote DB. */
+ char *remoteSqlPassword; /* Password for remote DB. */
+ char *remoteSqlDatabase; /* Database in remote DB. */
+ char *remoteSqlTable; /* Table name in remote DB. */
+
char *otherDb; /* Other database for an axt track. */
unsigned short private; /* True(1) if private, false(0) otherwise. */
float priority; /* Tracks are drawn in priority order. */
@@ -415,8 +422,11 @@
void removeTrackFromGroup(struct track *track);
/* Remove track from group it is part of. */
+struct sqlConnection *remoteTrackConnection(struct track *tg);
+/* Get a connection to remote database as specified in remoteSql settings... */
+
int orientFromChar(char c);
/* Return 1 or -1 in place of + or - */
enum trackVisibility limitVisibility(struct track *tg);